import fire
from opinecli import init, config, auth, project, data, user, subscription, system, organization

__version = "0.2.1"
def version():
    print(f"Opine CLI version {__version}")
list
class Actions(object):
    def __init__(self):
        self.config = config.Config()
        self.auth = auth.SignIn()
        self.project = project.Project()
        self.data = data.Data()
        self.user = user.User()
        self.subscription = subscription.Subscription()
        self.system = system.System()
        self.org = organization.Org()

    def init(self,endpoint="https://api.opine.world"):
        init.Init().start(endpoint)

    def version(self):
        self.version = version()

def main():
    fire.Fire(Actions)

if __name__ == '__main__':
    main()


import requests
import json
import tabulate
import pandas as pd
from opinecli.config import ConfigUtils
from opinecli.project import ProjectUtils

class Org(object):
    def __init__(self):
        self.__config_utils = ConfigUtils()

    
    def stats(self, org_id=''):
        """ Get system stats"""
        if not org_id:
            return "An org id is required"
        config_data = self.__config_utils.get()
        params = {'org_id': org_id}
        headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        result = requests.post(f'{config_data["api_endpoint"]}/org/stats', json=params, headers=headers)
        print()
        print(json.dumps(result.json()['results'], indent=2, sort_keys=True))
        print()

    # def users(self):
    #     """ Get stat of all users"""
    #     config_data = self.__config_utils.get()
    #     params = {}
    #     headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
    #     result = requests.post(f'{config_data["api_endpoint"]}/org/stat', json=params, headers=headers)
    #     print(result)
    #     # print()
    #     # print(json.dumps(result.json()['results'], indent=2, sort_keys=True))
    #     # print()

    


import requests
import json
import tabulate
import pandas as pd
from opinecli.config import ConfigUtils
from opinecli.user import UserUtils

class Subscription(object):
    def __init__(self):
        self.__config_utils = ConfigUtils()
    
    def count(self):
        """ 
        Count number of user accounts
        """
        config_data = self.__config_utils.get()
        
        
        # params = {"id":project_id,"user_id":config_data["user"]["id"]}        
        # headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        # result = requests.post(f'{config_data["api_endpoint"]}/users/stats', json=params, headers=headers)
        # stats = result.json()['results']
        # stats['data_values'] = stats['fields'] * stats['data_records']
        # print(f"Records counts: {stats['data_records']}")
        print("Not yet available.")
    
    def stats(self):
        """ Get counts of various subscription types"""
        print("Not yet available.")

    def describe(self, username, user_id=''):   
        config_data = self.__config_utils.get()
        if username:
            user = UserUtils().get_user(username)
            if user:
                user_id  = user['id']
        if not user_id:
            user_id = config_data["user"]["id"]     
        if not user_id:
            print("user_id is required.")
            return
        
        params = {"user_id":user_id}       
        headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        result = requests.post(f'{config_data["api_endpoint"]}/profile/subscription', json=params, headers=headers)
        print()
        print(json.dumps(result.json()['results'], indent=2, sort_keys=True))
        print()

    def pay(self, username, user_id='', type='full'):
        """Confirm payment of user's subscription. Payment type can be 'full' or 'partial'"""
        config_data = self.__config_utils.get()
        if username:
            user = UserUtils().get_user(username)
            if user:
                user_id  = user['id']
        if not user_id:
            print("user_id is required.")
            return
        
        params = {"user_id":user_id, "full_payment": type}
        headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        result = requests.post(f'{config_data["api_endpoint"]}/payment/add', json=params, headers=headers)
        print()
        print(json.dumps(result.json()['results'], indent=2, sort_keys=True))
        print()

    def payments(self, username, user_id='',output='table'):
        """ Get a list of payments made by a user"""
        config_data = self.__config_utils.get()
        if username:
            user = UserUtils().get_user(username)
            if user:
                user_id  = user['id']
        if not user_id:
            user_id = config_data["user"]["id"]
        params = {"user_id": user_id}
        headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        result = requests.post(f'{config_data["api_endpoint"]}/subscription/payments', json=params, headers=headers)
        keys = ['subs_id','cycle_paid_for','full_payment', 'date_paid', 'reference_no', 'created']
        print()
        if not result.json()['results']:
            print("No data available.")
            return

        if output == 'json':
            data = [{key: item[key] for key in keys} for item in result.json()['results']] 
            print(json.dumps(data, indent=2))
        elif output == 'table':
            df = pd.DataFrame(result.json()['results'])
            df.sort_values(by=['created'])
            df = df[keys]
            print(tabulate.tabulate(df, headers=keys, tablefmt="simple", colalign=("left",)))
        print()



import json
from opinecli.config import ConfigUtils
from opinecli import auth 

class Init(object):
    def __init__(self):
        pass
    
    def start(self, endpoint="https://api.opine.world"):
        ConfigUtils().set("api_endpoint", endpoint)
        auth.SignIn().login()


    



import requests
import json
import getpass
from opinecli.config import ConfigUtils

class SignIn(object):
       
    def login(self):
        _config_utils = ConfigUtils()
        username = input("Email: ")
        password = getpass.getpass("Password: ")
        config_data = _config_utils.get()
        params = {"email": username, "password": password}
        headers = {"content-type": "application/json"}
        result = requests.post(f'{config_data["api_endpoint"]}/login', json=params, headers=headers)
        if result.status_code == 200:
            print("\nLogin successful")
            _config_utils.set("user", result.json()['results'])
            # print(result.json()['results'])
        else:
            print("\nLogin failed!")

        

    def revoke(self):
        _config_utils = ConfigUtils()
        _config_utils.remove("user")
        print("Credentials and auth tokens revoked!")


    



import os
import requests
import json
import tabulate
import pandas as pd
from colorama import Fore, Style
from opinecli.config import ConfigUtils
from opinecli.user import UserUtils

class Project(object):
    def __init__(self):
        self.__config_utils = ConfigUtils() 
    
    def list(self, username='', user_id='', org='o', output='table'):
        config_data = self.__config_utils.get()
        if username:
            user = UserUtils().get_user(username)
            if user:
                user_id  = user['id']
        if not user_id:
            user_id = config_data["user"]["id"]
        params = {"user_id": user_id,"org_id":org,"private":"1"}
        headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        result = requests.post(f'{config_data["api_endpoint"]}/projects/user', json=params, headers=headers)
        keys = ['id','title','owner_id', 'created', 'modified']
        print()

        if not result.json()['results']:
            print("No data available.")
            return

        if output == 'json':
            data = [{key: item[key] for key in keys} for item in result.json()['results']] 
            print(json.dumps(data, indent=2))
        elif output == 'table':
            df = pd.DataFrame(result.json()['results'])
            df = df[keys]
            print(tabulate.tabulate(df, headers=keys, tablefmt="simple", colalign=("left",)))
        print()

    def describe(self, project_id='', username='', user_id='', detail=0):
        config_data = self.__config_utils.get()
        if not project_id:
            project_id = ProjectUtils().get_default_project()
        if not project_id:
            return ""
        if username:
            print(username)
            user = UserUtils().get_user(username)
            if user:
                user_id  = user['id']
        if not user_id:
            user_id = config_data["user"]["id"]
        params = {"project_id":project_id, "user_id":user_id, "detailed": str(detail)}        
        headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        result = requests.post(f'{config_data["api_endpoint"]}/projects', json=params, headers=headers)
        print()
        print(json.dumps(result.json()['results'], indent=2, sort_keys=True))
        print()

    def stats(self, project_id='', username='', user_id='', output='table'):
        """ 
        Get project statistics
        """
        config_data = self.__config_utils.get()
        if not project_id:
            project_id = ProjectUtils().get_default_project()
        if not project_id:
            return ""
        if username:
            user = UserUtils().get_user(username)
            if user:
                user_id  = user['id']
        if not user_id:
            user_id = config_data["user"]["id"]
        params = {"project_id":project_id,"user_id":user_id}        
        headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        result = requests.post(f'{config_data["api_endpoint"]}/projects/stats', json=params, headers=headers)
        stats = result.json()['results']
        stats['data_values'] = stats['fields'] * stats['data_records']
        print()

        if not result.json()['results']:
            print("No data available.")
            return
            
        if output == 'json':
            print(json.dumps(stats, indent=2))
        elif output == 'table':
            print(tabulate.tabulate([(k, v) for k,v in stats.items()]))
        print()

    def lock(self, project_id='', username='', user_id=''):
        config_data = self.__config_utils.get()
        if not project_id:
            project_id = ProjectUtils().get_default_project()
        if not project_id:
            return "Project id is required"
        if username:
            user = UserUtils().get_user(username)
            if user:
                user_id  = user['id']
        if not user_id:
            user_id = config_data["user"]["id"]
        
        params = {"project_id":project_id,"owner_id":config_data["user"]["id"], "locked":1}        
        headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        result = requests.post(f'{config_data["api_endpoint"]}/projects/lock', json=params, headers=headers)
        print()
        print(json.dumps(result.json()['message']['message']))
        print()

    def unlock(self, project_id='', username='', user_id=''):
        config_data = self.__config_utils.get()
        if not project_id:
            project_id = ProjectUtils().get_default_project()
        if not project_id:
            return "Project id is required"
        if username:
            user = UserUtils().get_user(username)
            if user:
                user_id  = user['id']
        if not user_id:
            user_id = config_data["user"]["id"]
        
        params = {"project_id":project_id,"owner_id":config_data["user"]["id"], "locked":0}        
        headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        result = requests.post(f'{config_data["api_endpoint"]}/projects/lock', json=params, headers=headers)
        print()
        print(json.dumps(result.json()['message']['message']))
        print()

class ProjectUtils(object):

    def __init__(self):
        self.__config_utils = ConfigUtils() 

    def get_default_project(self):
        config_data = self.__config_utils.get()
        if 'project_id' not in config_data:
            print()
            print(Fore.RED + 'A project id is required. See --help' + Style.RESET_ALL)
            print()
            return
        else:
            project_id = config_data['project_id']
            print()
            print(Style.BRIGHT + Fore.CYAN + "project_id: " + project_id + Style.RESET_ALL)
            return project_id


import requests
import json
import tabulate
import pandas as pd
from opinecli.config import ConfigUtils
# from opinecli.project import ProjectUtils

class User(object):
    def __init__(self):
        self.__config_utils = ConfigUtils()
    
    def count(self):
        """ 
        Count number of user accounts
        """
        config_data = self.__config_utils.get()
        
        
        # params = {"id":project_id,"user_id":config_data["user"]["id"]}        
        # headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        # result = requests.post(f'{config_data["api_endpoint"]}/users/stats', json=params, headers=headers)
        # stats = result.json()['results']
        # stats['data_values'] = stats['fields'] * stats['data_records']
        # print(f"Records counts: {stats['data_records']}")
        print("Not yet available.")
    
    def stats(self, username='', user_id=''):
        if not user_id and not username:
            print("A user name or user id is required.")
            return
        if username:
            user = UserUtils().get_user(username)
            if user:
                user_id  = user['id']
        if not user_id:
            return
        config_data = self.__config_utils.get()
        params = {"user_id":user_id}
        headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        result = requests.post(f'{config_data["api_endpoint"]}/user/stats/u', json=params, headers=headers)
        print()
        print(json.dumps(result.json()['results'], indent=2, sort_keys=True))
        print()

    def describe(self, username=''):        
        # if not username:
        #     print("user_id or username is required.")
        #     return
        # config_data = self.__config_utils.get()
        # params = {"search":username}       
        # headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        # result = requests.post(f'{config_data["api_endpoint"]}/profile/public', json=params, headers=headers)
        user = UserUtils().get_user(username)
        if user:
            print()
            print(json.dumps(user, indent=2, sort_keys=True))
        print()


class UserUtils(object):
    def __init__(self):
        self.__config_utils = ConfigUtils()

    def get_user(self, username):
        if not username:
            print("user_id or username is required.")
            return
        config_data = self.__config_utils.get()
        params = {"search":username}       
        headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        result = requests.post(f'{config_data["api_endpoint"]}/profile/public', json=params, headers=headers)
        user = {}
        if result:
            user = result.json()['results']
        if not user:
            print(f"User '{username}' not found.")
        return user


import json
import os.path

class Config(object):

    def list(self):
        config_utils = ConfigUtils()
        config_raw = config_utils.get()
        if type(config_raw) == dict:
            config_data = json.dumps(config_raw, indent=2, sort_keys=True)
            print(config_data)
        else:
            print(config_raw)
            
                
    def set(self, key, value):
        config_utils = ConfigUtils()
        config_utils.set(key, value)


class ConfigUtils():
    def __init__(self):
        self._config_path = os.path.expanduser("~") + '/opine_cli.cfg'
        self.default_endpoint = "https://api.opine.world"

    def get(self):
        if os.path.isfile(self._config_path) == False:
            return "No config file found. Run the command 'opine init'"
        else:
            file = open(self._config_path,)
            json_data = json.load(file)            
            file.close()
            return json_data
        
    def set(self, key, value):
        config_data = {}
        if not key or not value:
            print("KEY and/or VALUE cannot be empty.")
            print()
            return
        # read configs
        if os.path.isfile(self._config_path) == True:
            file = open(self._config_path,)
            config_data = json.load(file)
            file.close()

        config_data[key] = value
        jsondata = json.dumps(config_data, indent=2, sort_keys=True)
        # write all configs back to file
        file = open(self._config_path, "w")
        file.write(jsondata)
        file.close()
        return jsondata

    def remove(self, key):
        # read configs
        if os.path.isfile(self._config_path) == True:
            file = open(self._config_path,)
            config_data = json.load(file)
            file.close()
        if key in config_data:
            del config_data[key]
            jsondata = json.dumps(config_data, indent=2, sort_keys=True)
            # write all configs back to file
            file = open(self._config_path, "w")
            file.write(jsondata)
            file.close()
            return jsondata

    def set_default_api_endpoint(self):
        self.set("api_endpoint", "https://api.opine.world")
        



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="opine-cli",
    version="0.2.1",
    author="Opine @ Cognate Systems",
    author_email="info@opine.world",
    description="A command line interface for Opine",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://www.opine.world",
    project_urls={
        "Bug Tracker": "https://www.opine.world",
    },
    install_requires=[
        "pandas",
        "fire",
        "tabulate",
        "colorama"

    ],
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "."},
    packages=setuptools.find_packages(where="."),
    python_requires=">=3.6",
    entry_points={
        'console_scripts': [
            'opine=opinecli.cli:main',  # command=package.module:function
        ],
    },
)


import requests
import json
import tabulate
import pandas as pd
from opinecli.config import ConfigUtils
from opinecli.project import ProjectUtils

class System(object):
    def __init__(self):
        self.__config_utils = ConfigUtils()

    
    def stats(self):
        """ Get system stats"""
        config_data = self.__config_utils.get()
        params = {}
        headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        result = requests.post(f'{config_data["api_endpoint"]}/system/stats', json=params, headers=headers)
        print()
        print(json.dumps(result.json()['results'], indent=2, sort_keys=True))
        print()

    def users(self):
        """ Get stat of all users"""
        config_data = self.__config_utils.get()
        params = {}
        headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        result = requests.post(f'{config_data["api_endpoint"]}/users/stats', json=params, headers=headers)
        print(result)
        # print()
        # print(json.dumps(result.json()['results'], indent=2, sort_keys=True))
        # print()

    


import requests
import json
import tabulate
import pandas as pd
from opinecli.config import ConfigUtils
from opinecli.project import ProjectUtils

class Data(object):
    def __init__(self):
        self.__config_utils = ConfigUtils()
    
    def count(self, project_id=''):
        """ 
        Count project data records. And empty project id defaults to the last project id saved in config.
        """
        config_data = self.__config_utils.get()
        
        if not project_id:
            project_id = ProjectUtils().get_default_project()
        if not project_id:
            return ""
        params = {"id":project_id,"user_id":config_data["user"]["id"]}        
        headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        result = requests.post(f'{config_data["api_endpoint"]}/projects/stats', json=params, headers=headers)
        stats = result.json()['results']
        stats['data_values'] = stats['fields'] * stats['data_records']
        print(f"Records counts: {stats['data_records']}")
        print()
    
    def list(self, project_id='', output='table'):
        if not project_id:
            project_id = ProjectUtils().get_default_project()
        if not project_id:
            return ""
        config_data = self.__config_utils.get()
        params = {"projectid":project_id,"filters":[],"coded":1,"sortby":"data._id","sortdir":"descending","page":1,"limit":"1000000"}
        headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        result = requests.post(f'{config_data["api_endpoint"]}/data/all', json=params, headers=headers)
        keys = ['rid','xstatus', 'username', 'xcreated','xfinish', 'xsource', 'xsourceversion']
        data = [{key: item[key] for key in keys} for item in result.json()['results']['records']] 
        print()
        if not result.json()['results']:
            print("No data available.")
            return
            
        if output == 'json':            
            print(json.dumps(data, indent=2))
        elif output == 'table':
            df = pd.DataFrame(data)
            df = df[keys]
            print(tabulate.tabulate(df, headers=keys, tablefmt="simple", colalign=("left",)))
        print()

    def describe(self, project_id='', record_id=''):
        if not project_id:
            project_id = ProjectUtils().get_default_project()
        if not project_id:
            return
        if not record_id:
            print("record_id is required.")
            return
        config_data = self.__config_utils.get()
        params = {"project_id":project_id,"record":record_id}       
        headers = {"content-type": "application/json", "authorization": f'Token {config_data["user"]["access_token"]}'}        
        result = requests.post(f'{config_data["api_endpoint"]}/data/project', json=params, headers=headers)
        print()
        print(json.dumps(result.json()['results'], indent=2, sort_keys=True))
        print()